AxoupdateError

Enum AxoupdateError 

pub enum AxoupdateError {
Show 28 variants Reqwest(Error), Io(Error), CaminoPathBuf(FromPathBufError), Homedir(GetHomeError), Axoasset(AxoassetError), Axoprocess(AxoprocessError), Axotag(TagError), Gazenot(GazenotError), Version(Error), UrlParseError(ParseError), CaminoConversionFailed { path: PathBuf, }, BackendDisabled { backend: String, }, ConfigFetchFailed { app_name: String, }, ReceiptLoadFailed { app_name: String, }, NoReceipt { app_name: String, }, NoAppName {}, NoAppNamePassed {}, NoHome {}, NoInstallerForPackage {}, NoStableReleases { app_name: String, }, ReleaseNotFound { name: String, app_name: String, }, VersionNotFound { name: String, app_name: String, version: String, }, UpdateSelf {}, NotConfigured { missing_field: String, }, InstallFailed { status: Option<i32>, stdout: Option<String>, stderr: Option<String>, }, CleanupFailed {}, MultipleGitHubAPIs { ghe_env_var: String, github_env_var: String, }, GitHubDomainParseError { env_var: String, ghe_env_var: String, url: String, },
}
An enum representing all of this crate’s errors

Variants



Reqwest(Error)

Passed through from Reqwest



Io(Error)

Passed through from std::io::Error



CaminoPathBuf(FromPathBufError)

Passed through from Camino



Homedir(GetHomeError)

Passed through from homedir



Axoasset(AxoassetError)

Passed through from axoasset



Axoprocess(AxoprocessError)

Passed through from axoprocess



Axotag(TagError)

Passed through from axotag



Gazenot(GazenotError)

Passed through from gazenot



Version(Error)

Failed to parse a version



UrlParseError(ParseError)

Failed to parse a URL



CaminoConversionFailed

Failure when converting a PathBuf to a Utf8PathBuf

Fields

path: PathBuf

The path which Camino failed to convert



BackendDisabled

Indicates that the only updates available are located at a source this crate isn’t configured to support. This is returned if the appropriate source is disabled via features.

Fields

backend: String

The name of the backend



ConfigFetchFailed

Indicates that axoupdater wasn’t able to determine the config file path for this app. This path is where install receipts are located.

Fields

app_name: String

This app’s name



ReceiptLoadFailed

Indicates that the install receipt for this app couldn’t be read.

Fields

app_name: String

This app’s name



NoReceipt

Not a generic receipt load failure, but the receipt itself doesn’t exist.

Fields

app_name: String

This app’s name



NoAppName

Indicates that this app’s name couldn’t be determined when trying to autodetect it.



NoAppNamePassed

Indicates that no app name was specified before the updater process began.



NoHome

Indicates that the home directory couldn’t be determined.



NoInstallerForPackage

Indicates that no installer is available for this OS when looking up the latest release.



NoStableReleases

Indicates that no stable releases exist for the app being updated.

Fields

app_name: String

This app’s name



ReleaseNotFound

Indicates that no releases exist for this app at all.

Fields

name: String

The workspace’s name

app_name: String

This app’s name



VersionNotFound

Indicates that no releases exist for this app at all.

Fields

name: String

The workspace’s name

app_name: String

This app’s name

version: String

The version we failed to find



UpdateSelf

This error catches an edge case where the axoupdater executable was run under its default filename, “axoupdater”, instead of being installed under an app-specific name.



NotConfigured

Indicates that a mandatory config field wasn’t specified before the update process ran.

Fields

missing_field: String

The name of the missing field



InstallFailed

Indicates the installation failed for some reason we’re not sure of

Fields

status: Option<i32>

The status code from the underlying process, if any

stdout: Option<String>

The stdout, decoded to UTF-8. This will be None if it was piped to the terminal when running the installer.

stderr: Option<String>

The stderr, decoded to UTF-8. This will be None if it was piped to the terminal when running the installer.



CleanupFailed

self_replace/self_delete failed



MultipleGitHubAPIs

User passed conflicting GitHub API environment variables

Fields

ghe_env_var: String

The GitHub Enterprise env var

github_env_var: String

The GitHub env var



GitHubDomainParseError

Couldn’t parse the text domain (could be an IP, etc.)

Fields

env_var: String

The GitHub env var

ghe_env_var: String

The GitHub Enterprise env var

url: String

The supplied URL